@@ -75,8 +75,8 @@ int main(int argc, char *argv[])
         viewer.engine()->setNetworkAccessManagerFactory(factory);
 
 #ifdef Q_WS_MAEMO_5
-        viewer.engine()->addImportPath(QString("/opt/qtm12/imports"));
-        viewer.engine()->addPluginPath(QString("/opt/qtm12/plugins"));
+//        viewer.engine()->addImportPath(QString("/opt/qtm12/imports"));
+//        viewer.engine()->addPluginPath(QString("/opt/qtm12/plugins"));
         viewer.engine()->setOfflineStoragePath("/home/user/.config/cutetube");
         QDir path;
         path.setPath("/home/user/.config/cutetube");
