@@ -72,9 +72,13 @@
         <translation type="obsolete">cuteTube-QML - 0.8.0 in deutsch</translation>
     </message>
     <message>
-        <location filename="../AboutDialog.qml" line="44"/>
         <source>cuteTube-QML - 0.8.2</source>
-        <translation type="unfinished">cuteTube-QML - 0.8.2 in deutsch</translation>
+        <translation type="obsolete">cuteTube-QML - 0.8.2 in deutsch</translation>
+    </message>
+    <message>
+        <location filename="../AboutDialog.qml" line="44"/>
+        <source>cuteTube-QML - 0.8.3</source>
+        <translation type="unfinished">cuteTube-QML - 0.8.3 in deutsch</translation>
     </message>
     <message>
         <location filename="../AboutDialog.qml" line="56"/>
@@ -114,12 +118,12 @@
         <translation>Benutzername</translation>
     </message>
     <message>
-        <location filename="../AccountDetailsDialog.qml" line="95"/>
+        <location filename="../AccountDetailsDialog.qml" line="94"/>
         <source>Password</source>
         <translation>Passwort</translation>
     </message>
     <message>
-        <location filename="../AccountDetailsDialog.qml" line="108"/>
+        <location filename="../AccountDetailsDialog.qml" line="107"/>
         <source>Default?</source>
         <translation>Standard?</translation>
     </message>
@@ -199,13 +203,13 @@
         <translation type="obsolete">Vom Gerät löschen</translation>
     </message>
     <message>
-        <location filename="../ArchiveListView.qml" line="64"/>
+        <location filename="../ArchiveListView.qml" line="50"/>
         <source>Deleted from archive</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ArchiveListView.qml" line="67"/>
-        <location filename="../ArchiveListView.qml" line="86"/>
+        <location filename="../ArchiveListView.qml" line="53"/>
+        <location filename="../ArchiveListView.qml" line="72"/>
         <source>Unable to delete from archive</source>
         <translation type="unfinished"></translation>
     </message>
@@ -233,14 +237,14 @@
 <context>
     <name>CommentsDelegate</name>
     <message>
-        <location filename="../CommentsDelegate.qml" line="20"/>
-        <location filename="../CommentsDelegate.qml" line="22"/>
+        <location filename="../CommentsDelegate.qml" line="19"/>
+        <location filename="../CommentsDelegate.qml" line="21"/>
         <source>By </source>
         <translation>Von </translation>
     </message>
     <message>
-        <location filename="../CommentsDelegate.qml" line="21"/>
-        <location filename="../CommentsDelegate.qml" line="23"/>
+        <location filename="../CommentsDelegate.qml" line="20"/>
+        <location filename="../CommentsDelegate.qml" line="22"/>
         <source> on </source>
         <translation> am </translation>
     </message>
@@ -376,7 +380,7 @@
         <translation type="obsolete">Über</translation>
     </message>
     <message>
-        <location filename="../HomeView.qml" line="124"/>
+        <location filename="../HomeView.qml" line="121"/>
         <source>My Channel</source>
         <translation>Mein Kanal</translation>
     </message>
@@ -389,7 +393,7 @@
         <translation type="obsolete">Meistgesehen</translation>
     </message>
     <message>
-        <location filename="../HomeView.qml" line="194"/>
+        <location filename="../HomeView.qml" line="191"/>
         <source>Archive</source>
         <translation>Archiv</translation>
     </message>
@@ -448,7 +452,7 @@
         <translation type="obsolete">Beenden</translation>
     </message>
     <message>
-        <location filename="../MenuBar.qml" line="133"/>
+        <location filename="../MenuBar.qml" line="151"/>
         <source>Sort</source>
         <translation type="unfinished"></translation>
     </message>
@@ -460,37 +464,37 @@
         <translation type="obsolete">Video hochladen</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="98"/>
+        <location filename="../MyAccountView.qml" line="95"/>
         <source>My Uploads</source>
         <translation>Mein Uploads</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="104"/>
+        <location filename="../MyAccountView.qml" line="101"/>
         <source>Uploads</source>
         <translation>Uploads</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="122"/>
+        <location filename="../MyAccountView.qml" line="119"/>
         <source>My Favourites</source>
         <translation>Mein Favoriten</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="128"/>
+        <location filename="../MyAccountView.qml" line="125"/>
         <source>Favourites</source>
         <translation>Favoriten</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="152"/>
+        <location filename="../MyAccountView.qml" line="149"/>
         <source>Playlists</source>
         <translation>Wiedergabelisten</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="176"/>
+        <location filename="../MyAccountView.qml" line="173"/>
         <source>Subscriptions</source>
         <translation>Abonnement</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="191"/>
+        <location filename="../MyAccountView.qml" line="188"/>
         <source>Signed in as:</source>
         <translation>Angemeldet als:</translation>
     </message>
@@ -579,7 +583,7 @@
 <context>
     <name>PlaylistDelegate</name>
     <message>
-        <location filename="../PlaylistDelegate.qml" line="31"/>
+        <location filename="../PlaylistDelegate.qml" line="30"/>
         <source> videos</source>
         <translation>Videos</translation>
     </message>
@@ -611,12 +615,12 @@
         <translation type="obsolete">In Zwischenablage kopieren</translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="71"/>
+        <location filename="../PlaylistVideosView.qml" line="69"/>
         <source>Video(s) deleted from playlist</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="92"/>
+        <location filename="../PlaylistVideosView.qml" line="90"/>
         <source>No videos found</source>
         <translation>Keine Videos gefunden</translation>
     </message>
@@ -624,7 +628,7 @@
 <context>
     <name>PlaylistsView</name>
     <message>
-        <location filename="../PlaylistsView.qml" line="58"/>
+        <location filename="../PlaylistsView.qml" line="56"/>
         <source>New playlist created</source>
         <translation>Neue Wiedergabeliste erstellt</translation>
     </message>
@@ -633,7 +637,7 @@
         <translation type="obsolete">Neue Wiedergabeliste</translation>
     </message>
     <message>
-        <location filename="../PlaylistsView.qml" line="106"/>
+        <location filename="../PlaylistsView.qml" line="104"/>
         <source>No playlists found</source>
         <translation>Keine Wiedergabelisten gefunden</translation>
     </message>
@@ -765,6 +769,11 @@
         <source>720p</source>
         <translation></translation>
     </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="45"/>
+        <source>Night</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../SettingsDialog.qml" line="47"/>
         <source>Russian</source>
@@ -1102,7 +1111,7 @@
         <translation>Letzte abonnierte Videos</translation>
     </message>
     <message>
-        <location filename="../SubscriptionsView.qml" line="45"/>
+        <location filename="../SubscriptionsView.qml" line="43"/>
         <source>You have unsubscribed to this channel</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1115,7 +1124,7 @@
         <translation type="obsolete">Letzte abonnierte Videos</translation>
     </message>
     <message>
-        <location filename="../SubscriptionsView.qml" line="104"/>
+        <location filename="../SubscriptionsView.qml" line="102"/>
         <source>No subscriptions found</source>
         <translation>Keine Abonnements gefunden</translation>
     </message>
@@ -1375,12 +1384,12 @@
 <context>
     <name>UserVideosView</name>
     <message>
-        <location filename="../UserVideosView.qml" line="131"/>
+        <location filename="../UserVideosView.qml" line="129"/>
         <source>You have subscribed to &apos;</source>
         <translation>Du hast ein Abonnement bei</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="135"/>
+        <location filename="../UserVideosView.qml" line="133"/>
         <source>You have unsubscribed to &apos;</source>
         <translation>Abonnement gekündigt bei</translation>
     </message>
@@ -1409,27 +1418,27 @@
         <translation type="obsolete">In Zwischenablage kopieren</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="155"/>
+        <location filename="../UserVideosView.qml" line="153"/>
         <source>No videos found</source>
         <translation>Keine Videos gefunden</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="214"/>
+        <location filename="../UserVideosView.qml" line="212"/>
         <source>Subscribers</source>
         <translation>Abonnenten</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="228"/>
+        <location filename="../UserVideosView.qml" line="226"/>
         <source>Videos</source>
         <translation>Videos</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="251"/>
+        <location filename="../UserVideosView.qml" line="249"/>
         <source>Unsubscribe</source>
         <translation>Abonnement kündigen</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="251"/>
+        <location filename="../UserVideosView.qml" line="249"/>
         <source>Subscribe</source>
         <translation>Abonnieren</translation>
     </message>
@@ -1442,17 +1451,17 @@
         <translation>Keine Beschreibung</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="93"/>
+        <location filename="../VideoInfoView.qml" line="91"/>
         <source>Your comment has been added</source>
         <translation>Dein Kommentar wurde hinzugefügt</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="96"/>
+        <location filename="../VideoInfoView.qml" line="94"/>
         <source>Your rating has been added</source>
         <translation>Deine Bewertung wurde hinzugefügt</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="103"/>
+        <location filename="../VideoInfoView.qml" line="101"/>
         <source>Video shared on facebook</source>
         <translation>Video auf Facebook freigegeben</translation>
     </message>
@@ -1473,71 +1482,71 @@
         <translation type="obsolete">Auf Facebook freigeben</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="439"/>
-        <location filename="../VideoInfoView.qml" line="464"/>
-        <location filename="../VideoInfoView.qml" line="578"/>
+        <location filename="../VideoInfoView.qml" line="433"/>
+        <location filename="../VideoInfoView.qml" line="458"/>
+        <location filename="../VideoInfoView.qml" line="572"/>
         <source>You are not signed in to a YouTube account</source>
         <translation>Nicht bei einem YouTube Konto angemeldet</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="245"/>
+        <location filename="../VideoInfoView.qml" line="241"/>
         <source>Info</source>
         <translation>Info</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="284"/>
+        <location filename="../VideoInfoView.qml" line="279"/>
         <source>Comments</source>
         <translation>Kommentare</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="323"/>
+        <location filename="../VideoInfoView.qml" line="317"/>
         <source>Related</source>
         <translation>Ähnliche</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="408"/>
-        <location filename="../VideoInfoView.qml" line="411"/>
+        <location filename="../VideoInfoView.qml" line="402"/>
+        <location filename="../VideoInfoView.qml" line="405"/>
         <source>By </source>
         <translation>Von </translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="410"/>
-        <location filename="../VideoInfoView.qml" line="413"/>
+        <location filename="../VideoInfoView.qml" line="404"/>
+        <location filename="../VideoInfoView.qml" line="407"/>
         <source> on </source>
         <translation> am </translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="481"/>
+        <location filename="../VideoInfoView.qml" line="475"/>
         <source>Views</source>
         <translation>Aufrufe</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="495"/>
+        <location filename="../VideoInfoView.qml" line="489"/>
         <source>Description</source>
         <translation>Beschreibung</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="511"/>
+        <location filename="../VideoInfoView.qml" line="505"/>
         <source>Tags</source>
         <translation>Tags</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="521"/>
+        <location filename="../VideoInfoView.qml" line="515"/>
         <source>No tags</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="590"/>
+        <location filename="../VideoInfoView.qml" line="584"/>
         <source>No comments</source>
         <translation>Keine Kommentare</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="590"/>
+        <location filename="../VideoInfoView.qml" line="584"/>
         <source> comments</source>
         <translation>Kommentare</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="706"/>
+        <location filename="../VideoInfoView.qml" line="698"/>
         <source>No related videos</source>
         <translation>Keine ähnlichen Videos</translation>
     </message>
@@ -1545,17 +1554,17 @@
 <context>
     <name>VideoListDelegate</name>
     <message>
-        <location filename="../VideoListDelegate.qml" line="52"/>
+        <location filename="../VideoListDelegate.qml" line="51"/>
         <source>By </source>
         <translation>Von </translation>
     </message>
     <message>
-        <location filename="../VideoListDelegate.qml" line="52"/>
+        <location filename="../VideoListDelegate.qml" line="51"/>
         <source> on </source>
         <translation> am </translation>
     </message>
     <message>
-        <location filename="../VideoListDelegate.qml" line="102"/>
+        <location filename="../VideoListDelegate.qml" line="101"/>
         <source>Views</source>
         <translation>Aufrufe</translation>
     </message>
@@ -1587,12 +1596,12 @@
         <translation type="obsolete">In Zwischenablage kopieren</translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="82"/>
+        <location filename="../VideoListView.qml" line="80"/>
         <source>Video(s) deleted from favourites</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="104"/>
+        <location filename="../VideoListView.qml" line="102"/>
         <source>No videos found</source>
         <translation>Keine Videos gefunden</translation>
     </message>
@@ -1740,8 +1749,8 @@
         <translation>Upload ist komplett</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="397"/>
-        <location filename="../../../youtube.cpp" line="439"/>
+        <location filename="../../../youtube.cpp" line="392"/>
+        <location filename="../../../youtube.cpp" line="434"/>
         <source>Error: Unable to retrieve video</source>
         <translation>Fehler: Kann Video nicht empfangen</translation>
     </message>
@@ -1785,17 +1794,17 @@
         <translation type="obsolete">Video wurde zur Wiedergabeliste hinzugefügt</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="214"/>
+        <location filename="../main.qml" line="226"/>
         <source>New playlist created</source>
         <translation>Neue Wiedergabeliste erstellt</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="279"/>
+        <location filename="../main.qml" line="291"/>
         <source>Converting</source>
         <translation>Konvertiere</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="264"/>
+        <location filename="../main.qml" line="276"/>
         <source>Conversion of &apos;</source>
         <translation>Unterhaltung zwischen &apos;</translation>
     </message>
@@ -1895,17 +1904,17 @@
         <translation type="unfinished">Bewertung</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="205"/>
+        <location filename="../main.qml" line="217"/>
         <source>Video(s) added to favourites</source>
         <translation>Video(s) wurde zu Favoriten hinzugefügt</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="206"/>
+        <location filename="../main.qml" line="218"/>
         <source>Video(s) added to playlist</source>
         <translation>Video(s) wurde zur Wiedergabeliste hinzugefügt</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="264"/>
+        <location filename="../main.qml" line="276"/>
         <source>&apos; failed</source>
         <translation>&apos; gescheitert</translation>
     </message>
@@ -1918,22 +1927,22 @@
         <translation type="obsolete">Mobil</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="279"/>
+        <location filename="../main.qml" line="291"/>
         <source>Queued</source>
         <translation>in Warteschlange</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="279"/>
+        <location filename="../main.qml" line="291"/>
         <source>Paused</source>
         <translation>Pausiert</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="279"/>
+        <location filename="../main.qml" line="291"/>
         <source>Downloading</source>
         <translation>am Herrunterladen</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="279"/>
+        <location filename="../main.qml" line="291"/>
         <source>Failed</source>
         <translation>Fehlgeschlagen</translation>
     </message>
