@@ -52,9 +52,13 @@
         <translation type="obsolete">cuteTube-QML - 0.8.0 - Suomennos: d-iivil</translation>
     </message>
     <message>
-        <location filename="../AboutDialog.qml" line="44"/>
         <source>cuteTube-QML - 0.8.2</source>
-        <translation type="unfinished">cuteTube-QML - 0.8.2 - Suomennos: d-iivil</translation>
+        <translation type="obsolete">cuteTube-QML - 0.8.2 - Suomennos: d-iivil</translation>
+    </message>
+    <message>
+        <location filename="../AboutDialog.qml" line="44"/>
+        <source>cuteTube-QML - 0.8.3</source>
+        <translation type="unfinished">cuteTube-QML - 0.8.3 - Suomennos: d-iivil</translation>
     </message>
     <message>
         <location filename="../AboutDialog.qml" line="56"/>
@@ -86,12 +90,12 @@
         <translation>Käyttäjätunnus</translation>
     </message>
     <message>
-        <location filename="../AccountDetailsDialog.qml" line="95"/>
+        <location filename="../AccountDetailsDialog.qml" line="94"/>
         <source>Password</source>
         <translation>Salasana</translation>
     </message>
     <message>
-        <location filename="../AccountDetailsDialog.qml" line="108"/>
+        <location filename="../AccountDetailsDialog.qml" line="107"/>
         <source>Default?</source>
         <translation>Oletus?</translation>
     </message>
@@ -155,13 +159,13 @@
         <translation type="obsolete">Poista laitteesta</translation>
     </message>
     <message>
-        <location filename="../ArchiveListView.qml" line="64"/>
+        <location filename="../ArchiveListView.qml" line="50"/>
         <source>Deleted from archive</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ArchiveListView.qml" line="67"/>
-        <location filename="../ArchiveListView.qml" line="86"/>
+        <location filename="../ArchiveListView.qml" line="53"/>
+        <location filename="../ArchiveListView.qml" line="72"/>
         <source>Unable to delete from archive</source>
         <translation type="unfinished"></translation>
     </message>
@@ -185,14 +189,14 @@
 <context>
     <name>CommentsDelegate</name>
     <message>
-        <location filename="../CommentsDelegate.qml" line="20"/>
-        <location filename="../CommentsDelegate.qml" line="22"/>
+        <location filename="../CommentsDelegate.qml" line="19"/>
+        <location filename="../CommentsDelegate.qml" line="21"/>
         <source>By </source>
         <translation>Kirjoittaja: </translation>
     </message>
     <message>
-        <location filename="../CommentsDelegate.qml" line="21"/>
-        <location filename="../CommentsDelegate.qml" line="23"/>
+        <location filename="../CommentsDelegate.qml" line="20"/>
+        <location filename="../CommentsDelegate.qml" line="22"/>
         <source> on </source>
         <translation>milloin: </translation>
     </message>
@@ -320,7 +324,7 @@
         <translation type="obsolete">Tietoja</translation>
     </message>
     <message>
-        <location filename="../HomeView.qml" line="124"/>
+        <location filename="../HomeView.qml" line="121"/>
         <source>My Channel</source>
         <translation>Oma kanavani</translation>
     </message>
@@ -333,7 +337,7 @@
         <translation type="obsolete">Katsotuimmat</translation>
     </message>
     <message>
-        <location filename="../HomeView.qml" line="194"/>
+        <location filename="../HomeView.qml" line="191"/>
         <source>Archive</source>
         <translation>Kirjasto</translation>
     </message>
@@ -392,7 +396,7 @@
         <translation type="obsolete">Poistu</translation>
     </message>
     <message>
-        <location filename="../MenuBar.qml" line="133"/>
+        <location filename="../MenuBar.qml" line="151"/>
         <source>Sort</source>
         <translation type="unfinished"></translation>
     </message>
@@ -404,37 +408,37 @@
         <translation type="obsolete">Lataa video</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="98"/>
+        <location filename="../MyAccountView.qml" line="95"/>
         <source>My Uploads</source>
         <translation>Omat lataukset</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="104"/>
+        <location filename="../MyAccountView.qml" line="101"/>
         <source>Uploads</source>
         <translation>Lataukset</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="122"/>
+        <location filename="../MyAccountView.qml" line="119"/>
         <source>My Favourites</source>
         <translation>Omat suosikit</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="128"/>
+        <location filename="../MyAccountView.qml" line="125"/>
         <source>Favourites</source>
         <translation>Suosikit</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="152"/>
+        <location filename="../MyAccountView.qml" line="149"/>
         <source>Playlists</source>
         <translation>Soittolistat</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="176"/>
+        <location filename="../MyAccountView.qml" line="173"/>
         <source>Subscriptions</source>
         <translation>Syötteet</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="191"/>
+        <location filename="../MyAccountView.qml" line="188"/>
         <source>Signed in as:</source>
         <translation>Kirjautunut:</translation>
     </message>
@@ -519,7 +523,7 @@
 <context>
     <name>PlaylistDelegate</name>
     <message>
-        <location filename="../PlaylistDelegate.qml" line="31"/>
+        <location filename="../PlaylistDelegate.qml" line="30"/>
         <source> videos</source>
         <translation>videot</translation>
     </message>
@@ -551,12 +555,12 @@
         <translation type="obsolete">Kopioi leikepöydälle</translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="71"/>
+        <location filename="../PlaylistVideosView.qml" line="69"/>
         <source>Video(s) deleted from playlist</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="92"/>
+        <location filename="../PlaylistVideosView.qml" line="90"/>
         <source>No videos found</source>
         <translation>Ei videoita</translation>
     </message>
@@ -564,7 +568,7 @@
 <context>
     <name>PlaylistsView</name>
     <message>
-        <location filename="../PlaylistsView.qml" line="58"/>
+        <location filename="../PlaylistsView.qml" line="56"/>
         <source>New playlist created</source>
         <translation>Uusi soittolista luotu</translation>
     </message>
@@ -573,7 +577,7 @@
         <translation type="obsolete">Uusi soittolista</translation>
     </message>
     <message>
-        <location filename="../PlaylistsView.qml" line="106"/>
+        <location filename="../PlaylistsView.qml" line="104"/>
         <source>No playlists found</source>
         <translation>Ei soittolistoja</translation>
     </message>
@@ -667,6 +671,11 @@
         <source>Portrait</source>
         <translation>Pysty</translation>
     </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="45"/>
+        <source>Night</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../SettingsDialog.qml" line="47"/>
         <source>Russian</source>
@@ -1042,7 +1051,7 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SubscriptionsView.qml" line="45"/>
+        <location filename="../SubscriptionsView.qml" line="43"/>
         <source>You have unsubscribed to this channel</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1055,7 +1064,7 @@
         <translation type="obsolete">Viimeisimmät videot syötteestä</translation>
     </message>
     <message>
-        <location filename="../SubscriptionsView.qml" line="104"/>
+        <location filename="../SubscriptionsView.qml" line="102"/>
         <source>No subscriptions found</source>
         <translation>Ei syötteitä</translation>
     </message>
@@ -1307,12 +1316,12 @@
 <context>
     <name>UserVideosView</name>
     <message>
-        <location filename="../UserVideosView.qml" line="131"/>
+        <location filename="../UserVideosView.qml" line="129"/>
         <source>You have subscribed to &apos;</source>
         <translation>Olet tilannut syötteen: </translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="135"/>
+        <location filename="../UserVideosView.qml" line="133"/>
         <source>You have unsubscribed to &apos;</source>
         <translation>Olet perunut syötteen: </translation>
     </message>
@@ -1341,27 +1350,27 @@
         <translation type="obsolete">Kopioi leikepöydälle</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="155"/>
+        <location filename="../UserVideosView.qml" line="153"/>
         <source>No videos found</source>
         <translation>Ei videoita</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="214"/>
+        <location filename="../UserVideosView.qml" line="212"/>
         <source>Subscribers</source>
         <translation>Tilaajat</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="228"/>
+        <location filename="../UserVideosView.qml" line="226"/>
         <source>Videos</source>
         <translation>Videot</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="251"/>
+        <location filename="../UserVideosView.qml" line="249"/>
         <source>Unsubscribe</source>
         <translation>Peru tilaus</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="251"/>
+        <location filename="../UserVideosView.qml" line="249"/>
         <source>Subscribe</source>
         <translation>Tilaa</translation>
     </message>
@@ -1374,17 +1383,17 @@
         <translation>Ei kuvausta</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="93"/>
+        <location filename="../VideoInfoView.qml" line="91"/>
         <source>Your comment has been added</source>
         <translation>Kommenttisi tallennettiin</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="96"/>
+        <location filename="../VideoInfoView.qml" line="94"/>
         <source>Your rating has been added</source>
         <translation>Arviosi tallennettiin</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="103"/>
+        <location filename="../VideoInfoView.qml" line="101"/>
         <source>Video shared on facebook</source>
         <translation>Video jaettu facebookkiin</translation>
     </message>
@@ -1405,71 +1414,71 @@
         <translation type="obsolete">Jaa facebookin kautta</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="439"/>
-        <location filename="../VideoInfoView.qml" line="464"/>
-        <location filename="../VideoInfoView.qml" line="578"/>
+        <location filename="../VideoInfoView.qml" line="433"/>
+        <location filename="../VideoInfoView.qml" line="458"/>
+        <location filename="../VideoInfoView.qml" line="572"/>
         <source>You are not signed in to a YouTube account</source>
         <translation>Et ole kirjautunut YouTubeen</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="245"/>
+        <location filename="../VideoInfoView.qml" line="241"/>
         <source>Info</source>
         <translation>Tietoa</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="284"/>
+        <location filename="../VideoInfoView.qml" line="279"/>
         <source>Comments</source>
         <translation>Kommentit</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="323"/>
+        <location filename="../VideoInfoView.qml" line="317"/>
         <source>Related</source>
         <translation>Liittyvät</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="408"/>
-        <location filename="../VideoInfoView.qml" line="411"/>
+        <location filename="../VideoInfoView.qml" line="402"/>
+        <location filename="../VideoInfoView.qml" line="405"/>
         <source>By </source>
         <translation>Kirjoittaja: </translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="410"/>
-        <location filename="../VideoInfoView.qml" line="413"/>
+        <location filename="../VideoInfoView.qml" line="404"/>
+        <location filename="../VideoInfoView.qml" line="407"/>
         <source> on </source>
         <translation> milloin: </translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="481"/>
+        <location filename="../VideoInfoView.qml" line="475"/>
         <source>Views</source>
         <translation>Katseluja</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="495"/>
+        <location filename="../VideoInfoView.qml" line="489"/>
         <source>Description</source>
         <translation>Kuvaus</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="511"/>
+        <location filename="../VideoInfoView.qml" line="505"/>
         <source>Tags</source>
         <translation>Tagit</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="521"/>
+        <location filename="../VideoInfoView.qml" line="515"/>
         <source>No tags</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="590"/>
+        <location filename="../VideoInfoView.qml" line="584"/>
         <source>No comments</source>
         <translation>Ei kommentteja</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="590"/>
+        <location filename="../VideoInfoView.qml" line="584"/>
         <source> comments</source>
         <translation>kommentit</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="706"/>
+        <location filename="../VideoInfoView.qml" line="698"/>
         <source>No related videos</source>
         <translation>Ei liittyviä videoita</translation>
     </message>
@@ -1477,17 +1486,17 @@
 <context>
     <name>VideoListDelegate</name>
     <message>
-        <location filename="../VideoListDelegate.qml" line="52"/>
+        <location filename="../VideoListDelegate.qml" line="51"/>
         <source>By </source>
         <translation>Kirjoittaja: </translation>
     </message>
     <message>
-        <location filename="../VideoListDelegate.qml" line="52"/>
+        <location filename="../VideoListDelegate.qml" line="51"/>
         <source> on </source>
         <translation>milloin: </translation>
     </message>
     <message>
-        <location filename="../VideoListDelegate.qml" line="102"/>
+        <location filename="../VideoListDelegate.qml" line="101"/>
         <source>Views</source>
         <translation>Katseluja</translation>
     </message>
@@ -1519,12 +1528,12 @@
         <translation type="obsolete">Kopioi leikepöydälle</translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="82"/>
+        <location filename="../VideoListView.qml" line="80"/>
         <source>Video(s) deleted from favourites</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="104"/>
+        <location filename="../VideoListView.qml" line="102"/>
         <source>No videos found</source>
         <translation>Ei videoita</translation>
     </message>
@@ -1672,8 +1681,8 @@
         <translation>Lataus valmistui</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="397"/>
-        <location filename="../../../youtube.cpp" line="439"/>
+        <location filename="../../../youtube.cpp" line="392"/>
+        <location filename="../../../youtube.cpp" line="434"/>
         <source>Error: Unable to retrieve video</source>
         <translation>Virhe: videon lataus epäonnistui</translation>
     </message>
@@ -1717,17 +1726,17 @@
         <translation type="obsolete">Video lisätty soittolistalle</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="214"/>
+        <location filename="../main.qml" line="226"/>
         <source>New playlist created</source>
         <translation>Uusi soittolista luotu</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="279"/>
+        <location filename="../main.qml" line="291"/>
         <source>Converting</source>
         <translation>Muunnetaan</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="264"/>
+        <location filename="../main.qml" line="276"/>
         <source>Conversion of &apos;</source>
         <translation>Muunto: </translation>
     </message>
@@ -1827,17 +1836,17 @@
         <translation type="unfinished">Arvio</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="205"/>
+        <location filename="../main.qml" line="217"/>
         <source>Video(s) added to favourites</source>
         <translation>Video(t) lisätty suosikkeihin</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="206"/>
+        <location filename="../main.qml" line="218"/>
         <source>Video(s) added to playlist</source>
         <translation>Video(t) lisätty soittolistalle</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="264"/>
+        <location filename="../main.qml" line="276"/>
         <source>&apos; failed</source>
         <translation> epäonnistui</translation>
     </message>
@@ -1846,22 +1855,22 @@
         <translation type="obsolete">Mobiili</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="279"/>
+        <location filename="../main.qml" line="291"/>
         <source>Queued</source>
         <translation>Jonossa</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="279"/>
+        <location filename="../main.qml" line="291"/>
         <source>Paused</source>
         <translation>Keskeytetty</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="279"/>
+        <location filename="../main.qml" line="291"/>
         <source>Downloading</source>
         <translation>Ladataan</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="279"/>
+        <location filename="../main.qml" line="291"/>
         <source>Failed</source>
         <translation type="unfinished"></translation>
     </message>
