@@ -40,9 +40,13 @@
         <translation type="obsolete">cuteTube-QML - 0.8.0</translation>
     </message>
     <message>
-        <location filename="../AboutDialog.qml" line="44"/>
         <source>cuteTube-QML - 0.8.2</source>
-        <translation type="unfinished">cuteTube-QML - 0.8.2</translation>
+        <translation type="obsolete">cuteTube-QML - 0.8.2</translation>
+    </message>
+    <message>
+        <location filename="../AboutDialog.qml" line="44"/>
+        <source>cuteTube-QML - 0.8.3</source>
+        <translation type="unfinished">cuteTube-QML - 0.8.3</translation>
     </message>
     <message>
         <location filename="../AboutDialog.qml" line="56"/>
@@ -74,12 +78,12 @@
         <translation>Имя пользователя</translation>
     </message>
     <message>
-        <location filename="../AccountDetailsDialog.qml" line="95"/>
+        <location filename="../AccountDetailsDialog.qml" line="94"/>
         <source>Password</source>
         <translation>Пароль</translation>
     </message>
     <message>
-        <location filename="../AccountDetailsDialog.qml" line="108"/>
+        <location filename="../AccountDetailsDialog.qml" line="107"/>
         <source>Default?</source>
         <translation>По Умолчанию?</translation>
     </message>
@@ -143,13 +147,13 @@
         <translation type="obsolete">Удалить с устройства</translation>
     </message>
     <message>
-        <location filename="../ArchiveListView.qml" line="64"/>
+        <location filename="../ArchiveListView.qml" line="50"/>
         <source>Deleted from archive</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ArchiveListView.qml" line="67"/>
-        <location filename="../ArchiveListView.qml" line="86"/>
+        <location filename="../ArchiveListView.qml" line="53"/>
+        <location filename="../ArchiveListView.qml" line="72"/>
         <source>Unable to delete from archive</source>
         <translation type="unfinished"></translation>
     </message>
@@ -173,14 +177,14 @@
 <context>
     <name>CommentsDelegate</name>
     <message>
-        <location filename="../CommentsDelegate.qml" line="20"/>
-        <location filename="../CommentsDelegate.qml" line="22"/>
+        <location filename="../CommentsDelegate.qml" line="19"/>
+        <location filename="../CommentsDelegate.qml" line="21"/>
         <source>By </source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../CommentsDelegate.qml" line="21"/>
-        <location filename="../CommentsDelegate.qml" line="23"/>
+        <location filename="../CommentsDelegate.qml" line="20"/>
+        <location filename="../CommentsDelegate.qml" line="22"/>
         <source> on </source>
         <translation></translation>
     </message>
@@ -304,7 +308,7 @@
         <translation type="obsolete">О приложении</translation>
     </message>
     <message>
-        <location filename="../HomeView.qml" line="124"/>
+        <location filename="../HomeView.qml" line="121"/>
         <source>My Channel</source>
         <translation>Мой Канал</translation>
     </message>
@@ -317,7 +321,7 @@
         <translation type="obsolete">Популярные</translation>
     </message>
     <message>
-        <location filename="../HomeView.qml" line="194"/>
+        <location filename="../HomeView.qml" line="191"/>
         <source>Archive</source>
         <translation>Архив</translation>
     </message>
@@ -376,7 +380,7 @@
         <translation type="obsolete">Выход</translation>
     </message>
     <message>
-        <location filename="../MenuBar.qml" line="133"/>
+        <location filename="../MenuBar.qml" line="151"/>
         <source>Sort</source>
         <translation type="unfinished"></translation>
     </message>
@@ -388,37 +392,37 @@
         <translation type="obsolete">Загрузить видео</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="98"/>
+        <location filename="../MyAccountView.qml" line="95"/>
         <source>My Uploads</source>
         <translation>Загруженные</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="104"/>
+        <location filename="../MyAccountView.qml" line="101"/>
         <source>Uploads</source>
         <translation>Загруженные</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="122"/>
+        <location filename="../MyAccountView.qml" line="119"/>
         <source>My Favourites</source>
         <translation>Избранное</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="128"/>
+        <location filename="../MyAccountView.qml" line="125"/>
         <source>Favourites</source>
         <translation>Избранное</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="152"/>
+        <location filename="../MyAccountView.qml" line="149"/>
         <source>Playlists</source>
         <translation>Плейлисты</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="176"/>
+        <location filename="../MyAccountView.qml" line="173"/>
         <source>Subscriptions</source>
         <translation>Подписки</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="191"/>
+        <location filename="../MyAccountView.qml" line="188"/>
         <source>Signed in as:</source>
         <translation>Вы вошли как:</translation>
     </message>
@@ -503,7 +507,7 @@
 <context>
     <name>PlaylistDelegate</name>
     <message>
-        <location filename="../PlaylistDelegate.qml" line="31"/>
+        <location filename="../PlaylistDelegate.qml" line="30"/>
         <source> videos</source>
         <translation> видео</translation>
     </message>
@@ -535,12 +539,12 @@
         <translation type="obsolete">Скопировать в буфер</translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="71"/>
+        <location filename="../PlaylistVideosView.qml" line="69"/>
         <source>Video(s) deleted from playlist</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="92"/>
+        <location filename="../PlaylistVideosView.qml" line="90"/>
         <source>No videos found</source>
         <translation>Видео не найдено</translation>
     </message>
@@ -548,7 +552,7 @@
 <context>
     <name>PlaylistsView</name>
     <message>
-        <location filename="../PlaylistsView.qml" line="58"/>
+        <location filename="../PlaylistsView.qml" line="56"/>
         <source>New playlist created</source>
         <translation>Новый плейлист создан</translation>
     </message>
@@ -557,7 +561,7 @@
         <translation type="obsolete">Новый плейлист</translation>
     </message>
     <message>
-        <location filename="../PlaylistsView.qml" line="106"/>
+        <location filename="../PlaylistsView.qml" line="104"/>
         <source>No playlists found</source>
         <translation>Плейлисты не найдены</translation>
     </message>
@@ -689,6 +693,11 @@
         <source>720p</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="45"/>
+        <source>Night</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../SettingsDialog.qml" line="46"/>
         <source>Dutch</source>
@@ -1026,7 +1035,7 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SubscriptionsView.qml" line="45"/>
+        <location filename="../SubscriptionsView.qml" line="43"/>
         <source>You have unsubscribed to this channel</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1039,7 +1048,7 @@
         <translation type="obsolete">Последнее в подписках</translation>
     </message>
     <message>
-        <location filename="../SubscriptionsView.qml" line="104"/>
+        <location filename="../SubscriptionsView.qml" line="102"/>
         <source>No subscriptions found</source>
         <translation>Подписок не найдено</translation>
     </message>
@@ -1291,12 +1300,12 @@
 <context>
     <name>UserVideosView</name>
     <message>
-        <location filename="../UserVideosView.qml" line="131"/>
+        <location filename="../UserVideosView.qml" line="129"/>
         <source>You have subscribed to &apos;</source>
         <translation>Вы подписались на &apos;</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="135"/>
+        <location filename="../UserVideosView.qml" line="133"/>
         <source>You have unsubscribed to &apos;</source>
         <translation>Вы больше не подписаны на &apos;</translation>
     </message>
@@ -1325,27 +1334,27 @@
         <translation type="obsolete">Копировать в буфер</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="155"/>
+        <location filename="../UserVideosView.qml" line="153"/>
         <source>No videos found</source>
         <translation>Видео не найдено</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="214"/>
+        <location filename="../UserVideosView.qml" line="212"/>
         <source>Subscribers</source>
         <translation>Подписчики</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="228"/>
+        <location filename="../UserVideosView.qml" line="226"/>
         <source>Videos</source>
         <translation>Видео</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="251"/>
+        <location filename="../UserVideosView.qml" line="249"/>
         <source>Unsubscribe</source>
         <translation>Отписаться</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="251"/>
+        <location filename="../UserVideosView.qml" line="249"/>
         <source>Subscribe</source>
         <translation>Подписаться</translation>
     </message>
@@ -1358,17 +1367,17 @@
         <translation>Нет описания</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="93"/>
+        <location filename="../VideoInfoView.qml" line="91"/>
         <source>Your comment has been added</source>
         <translation>Ваш комментарий добавлен</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="96"/>
+        <location filename="../VideoInfoView.qml" line="94"/>
         <source>Your rating has been added</source>
         <translation>Ваша оценка добавлена</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="103"/>
+        <location filename="../VideoInfoView.qml" line="101"/>
         <source>Video shared on facebook</source>
         <translation>Видео опубликовано на Facebook</translation>
     </message>
@@ -1389,71 +1398,71 @@
         <translation type="obsolete">Опубликовать на Facebook</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="439"/>
-        <location filename="../VideoInfoView.qml" line="464"/>
-        <location filename="../VideoInfoView.qml" line="578"/>
+        <location filename="../VideoInfoView.qml" line="433"/>
+        <location filename="../VideoInfoView.qml" line="458"/>
+        <location filename="../VideoInfoView.qml" line="572"/>
         <source>You are not signed in to a YouTube account</source>
         <translation>Вы не вошли в аккаунт YouTube</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="245"/>
+        <location filename="../VideoInfoView.qml" line="241"/>
         <source>Info</source>
         <translation>Инфо</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="284"/>
+        <location filename="../VideoInfoView.qml" line="279"/>
         <source>Comments</source>
         <translation>Комментарий</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="323"/>
+        <location filename="../VideoInfoView.qml" line="317"/>
         <source>Related</source>
         <translation>Похожие</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="408"/>
-        <location filename="../VideoInfoView.qml" line="411"/>
+        <location filename="../VideoInfoView.qml" line="402"/>
+        <location filename="../VideoInfoView.qml" line="405"/>
         <source>By </source>
         <translation>От </translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="410"/>
-        <location filename="../VideoInfoView.qml" line="413"/>
+        <location filename="../VideoInfoView.qml" line="404"/>
+        <location filename="../VideoInfoView.qml" line="407"/>
         <source> on </source>
         <translation> от </translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="481"/>
+        <location filename="../VideoInfoView.qml" line="475"/>
         <source>Views</source>
         <translation>Просмотров</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="495"/>
+        <location filename="../VideoInfoView.qml" line="489"/>
         <source>Description</source>
         <translation>Описание</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="511"/>
+        <location filename="../VideoInfoView.qml" line="505"/>
         <source>Tags</source>
         <translation>Теги</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="521"/>
+        <location filename="../VideoInfoView.qml" line="515"/>
         <source>No tags</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="590"/>
+        <location filename="../VideoInfoView.qml" line="584"/>
         <source>No comments</source>
         <translation>Нет комментариев</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="590"/>
+        <location filename="../VideoInfoView.qml" line="584"/>
         <source> comments</source>
         <translation> комментариев</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="706"/>
+        <location filename="../VideoInfoView.qml" line="698"/>
         <source>No related videos</source>
         <translation>Нет похожих видео</translation>
     </message>
@@ -1461,17 +1470,17 @@
 <context>
     <name>VideoListDelegate</name>
     <message>
-        <location filename="../VideoListDelegate.qml" line="52"/>
+        <location filename="../VideoListDelegate.qml" line="51"/>
         <source>By </source>
         <translation>От </translation>
     </message>
     <message>
-        <location filename="../VideoListDelegate.qml" line="52"/>
+        <location filename="../VideoListDelegate.qml" line="51"/>
         <source> on </source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoListDelegate.qml" line="102"/>
+        <location filename="../VideoListDelegate.qml" line="101"/>
         <source>Views</source>
         <translation>Просмотров</translation>
     </message>
@@ -1503,12 +1512,12 @@
         <translation type="obsolete">Копировать в буфер</translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="82"/>
+        <location filename="../VideoListView.qml" line="80"/>
         <source>Video(s) deleted from favourites</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="104"/>
+        <location filename="../VideoListView.qml" line="102"/>
         <source>No videos found</source>
         <translation>Видео не найдены</translation>
     </message>
@@ -1572,8 +1581,8 @@
         <translation>Загрузка завершена</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="397"/>
-        <location filename="../../../youtube.cpp" line="439"/>
+        <location filename="../../../youtube.cpp" line="392"/>
+        <location filename="../../../youtube.cpp" line="434"/>
         <source>Error: Unable to retrieve video</source>
         <translation>Ошибка: Невозможно получить видео</translation>
     </message>
@@ -1617,17 +1626,17 @@
         <translation type="obsolete">Видео добавлено в плейлист</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="214"/>
+        <location filename="../main.qml" line="226"/>
         <source>New playlist created</source>
         <translation>Новый плейлист создан</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="279"/>
+        <location filename="../main.qml" line="291"/>
         <source>Converting</source>
         <translation>Конвертирую</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="264"/>
+        <location filename="../main.qml" line="276"/>
         <source>Conversion of &apos;</source>
         <translation>Конвертация &apos;</translation>
     </message>
@@ -1727,17 +1736,17 @@
         <translation type="unfinished">Рейтингу</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="205"/>
+        <location filename="../main.qml" line="217"/>
         <source>Video(s) added to favourites</source>
         <translation>Видео добавлено в избранное</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="206"/>
+        <location filename="../main.qml" line="218"/>
         <source>Video(s) added to playlist</source>
         <translation>Видео добавлено в плейлист</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="264"/>
+        <location filename="../main.qml" line="276"/>
         <source>&apos; failed</source>
         <translation>&apos; не выполнена</translation>
     </message>
@@ -1746,22 +1755,22 @@
         <translation type="obsolete">Мобильное</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="279"/>
+        <location filename="../main.qml" line="291"/>
         <source>Queued</source>
         <translation>В очереди</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="279"/>
+        <location filename="../main.qml" line="291"/>
         <source>Paused</source>
         <translation>Пауза</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="279"/>
+        <location filename="../main.qml" line="291"/>
         <source>Downloading</source>
         <translation>Загружается</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="279"/>
+        <location filename="../main.qml" line="291"/>
         <source>Failed</source>
         <translation>Ошибка</translation>
     </message>
