@@ -147,7 +147,7 @@ function loadAccountView() {
 
     if (userIsSignedIn()) {
         var loader = viewsModel.children[windowView.currentIndex + 1];
-        windowView.currentItem.visible = false;
+        windowView.currentItem.opacity = 0;
         loader.source = "MyAccountView.qml";
         loader.item.uploads.connect(loadVideos);
         loader.item.favourites.connect(loadVideos);
@@ -167,7 +167,7 @@ function loadArchiveView() {
     /* Loads the view of previously downloaded videos */
 
     var loader = viewsModel.children[windowView.currentIndex + 1];
-    windowView.currentItem.visible = false;
+    windowView.currentItem.opacity = 0;
     loader.source = "ArchiveListView.qml";
     loader.item.playVideos.connect(loadPlaybackView);
     notificationArea.addTitle(qsTr("Archive"));
@@ -176,7 +176,7 @@ function loadArchiveView() {
 
 function loadVideos(feed, title) {
     var loader = viewsModel.children[windowView.currentIndex + 1];
-    windowView.currentItem.visible = false;
+    windowView.currentItem.opacity = 0;
     loader.source = "VideoListView.qml";
     loader.item.goToVideo.connect(loadVideoInfo);
     loader.item.setVideoFeed(feed);
@@ -186,7 +186,7 @@ function loadVideos(feed, title) {
 
 function loadUserVideos(username) {
     var loader = viewsModel.children[windowView.currentIndex + 1];
-    windowView.currentItem.visible = false;
+    windowView.currentItem.opacity = 0;
     loader.source = "UserVideosView.qml";
     loader.item.goToVideo.connect(loadVideoInfo);
     loader.item.getUserProfile(username);
@@ -196,7 +196,7 @@ function loadUserVideos(username) {
 
 function loadPlaylistVideos(playlistId, title) {
     var loader = viewsModel.children[windowView.currentIndex + 1];
-    windowView.currentItem.visible = false;
+    windowView.currentItem.opacity = 0;
     loader.source = "PlaylistVideosView.qml";
     loader.item.goToVideo.connect(loadVideoInfo);
     loader.item.setVideoFeed("http://gdata.youtube.com/feeds/api/playlists/" + playlistId + "?v=2&max-results=50");
@@ -206,7 +206,7 @@ function loadPlaylistVideos(playlistId, title) {
 
 function loadPlaylists() {
     var loader = viewsModel.children[windowView.currentIndex + 1];
-    windowView.currentItem.visible = false;
+    windowView.currentItem.opacity = 0;
     loader.source = "PlaylistsView.qml";
     loader.item.goToPlaylist.connect(loadPlaylistVideos);
     notificationArea.addTitle(qsTr("My Playlists"));
@@ -215,7 +215,7 @@ function loadPlaylists() {
 
 function loadSubscriptions() {
     var loader = viewsModel.children[windowView.currentIndex + 1];
-    windowView.currentItem.visible = false;
+    windowView.currentItem.opacity = 0;
     loader.source = "SubscriptionsView.qml";
     loader.item.goToUserVideos.connect(loadUserVideos);
     loader.item.goToNewSubVideos.connect(loadVideos);
@@ -225,7 +225,7 @@ function loadSubscriptions() {
 
 function loadVideoInfo(video) {
     var loader = viewsModel.children[windowView.currentIndex + 1];
-    windowView.currentItem.visible = false;
+    windowView.currentItem.opacity = 0;
     loader.source = "VideoInfoView.qml";
     loader.item.playVideo.connect(loadPlaybackView);
     loader.item.goToVideo.connect(loadVideoInfo);
@@ -239,7 +239,7 @@ function loadVideoInfo(video) {
 function loadPlaybackView(videoList) {
     Controller.setOrientation("landscape");
     var loader = viewsModel.children[windowView.currentIndex + 1];
-    windowView.currentItem.visible = false;
+    windowView.currentItem.opacity = 0;
     toggleControls(false);
     loader.source = "VideoPlaybackView.qml";
     notificationArea.addTitle(qsTr("Video Playback"));
@@ -251,7 +251,7 @@ function loadPlaybackView(videoList) {
 function youtubeSearch(query, order) {
     /* Perform a YouTube search and open video list window */
 
-    var encodedQuery = encodeURIComponent(query);
+    var encodedQuery = encodeURIComponent(query.replace(/\s.\s/gi, " "));
     var safe = Settings.getSetting("safeSearch");
     var videoFeed = ("http://gdata.youtube.com/feeds/api/videos?v=2&max-results=50&safeSearch=" + safe + "&q=%22"
                      + encodedQuery + "%22%7C" + encodedQuery.replace(" ", "+") + "&orderby=" + order);
