@@ -350,17 +350,12 @@ void YouTube::replyToComment(const QString &videoId, const QString &commentId, c
 }
 
 void YouTube::getVideoUrl(const QString &videoId) {
-    QString playerUrl = "http://www.youtube.com/get_video_info?&video_id=" + videoId.toAscii() + "&el=detailpage&ps=default&eurl=&gl=US&hl=en";
+    QString playerUrl = "http://www.youtube.com/get_video_info?&video_id=" + videoId + "&el=detailpage&ps=default&eurl=&gl=US&hl=en";
     QNetworkAccessManager *manager = new QNetworkAccessManager(this);
     QNetworkRequest request;
     request.setUrl(QUrl(playerUrl));
     connect(manager, SIGNAL(finished(QNetworkReply*)), this, SLOT(parseVideoPage(QNetworkReply*)));
     manager->get(request);
-
-//    QNetworkRequest request;
-//    request.setUrl(QUrl(playerUrl));
-//    QNetworkReply *reply = nam->get(request);
-//    connect(reply, SIGNAL(finished()), this, SLOT(parseVideoPage()));
 }
 
 void YouTube::parseVideoPage(QNetworkReply *reply) {
